@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import libcst
 from libcst import (
     BaseCompoundStatement,
@@ -14,6 +16,7 @@ from typing_extensions import Callable, Optional, Sequence
 
 from patchwork.common.context_strategy.position import Position
 
+from .langugues import PythonLanguage
 from .protocol import ContextStrategyProtocol
 
 
@@ -56,6 +59,7 @@ class _PythonCollector(libcst.CSTVisitor):
             end=code_range.end.line,
             start_col=code_range.start.column - 1,
             end_col=code_range.end.column,
+            language=PythonLanguage(),
         )
         self.positions.append(position)
         return position
@@ -90,14 +94,25 @@ class _FunctionCollector(_PythonCollector):
         position = self._visit(node)
         docstring_node = self._get_docstring_node(node.body)
         if docstring_node:
-            code_range = self.get_metadata(PositionProvider, docstring_node)
+            docstring_code_range = self.get_metadata(PositionProvider, docstring_node)
             comment_position = Position(
-                start=code_range.start.line - 1,
-                end=code_range.end.line,
-                start_col=code_range.start.column - 1,
-                end_col=code_range.end.column,
+                start=docstring_code_range.start.line - 1,
+                end=docstring_code_range.end.line,
+                start_col=docstring_code_range.start.column - 1,
+                end_col=docstring_code_range.end.column,
+                language=PythonLanguage(),
             )
             position.meta_positions["comment"] = comment_position
+
+        body_code_range = self.get_metadata(PositionProvider, node.body)
+        body_position = Position(
+            start=body_code_range.start.line - 1,
+            end=body_code_range.end.line,
+            start_col=body_code_range.start.column - 1,
+            end_col=body_code_range.end.column,
+            language=PythonLanguage(),
+        )
+        position.meta_positions["body"] = body_position
         return True
 
     def _get_docstring_node(
@@ -224,6 +239,10 @@ class PythonStrategy(ContextStrategyProtocol):
             return False
         return filename.endswith(".py") and len(src) > 0
 
+    @property
+    def language(self) -> PythonLanguage:
+        return PythonLanguage()
+
 
 class PythonFunctionStrategy(PythonStrategy):
     def __init__(self):
