@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import contextlib
+import fnmatch
 from pathlib import Path
 
 import git
@@ -123,11 +124,39 @@ class CommitChanges(Step):
         if self.enabled and self.branch_prefix == "" and self.branch_suffix == "":
             raise ValueError("Both branch_prefix and branch_suffix cannot be empty")
 
+    def __get_ignored_groks(self, repo: Repo) -> set[str]:
+        ignored_groks = set()
+        gitignore_file = Path(repo.working_tree_dir) / ".gitignore"
+        if not gitignore_file.is_file():
+            return ignored_groks
+        lines = gitignore_file.read_text().splitlines()
+        for line in lines:
+            stripped_line = line.strip()
+            if stripped_line.startswith("#") or stripped_line == "":
+                continue
+            ignored_groks.add(stripped_line)
+        return ignored_groks
+
+    def __get_repo_tracked_modified_files(self, repo: Repo) -> set[Path]:
+        repo_dir_path = Path(repo.working_tree_dir)
+        ignored_groks = self.__get_ignored_groks(repo)
+
+        repo_changed_files = set()
+        for item in repo.index.diff(None):
+            repo_changed_file = item.a_path
+            for ignored_grok in ignored_groks:
+                if fnmatch.fnmatch(repo_changed_file, ignored_grok):
+                    logger.warn(f'Ignoring file: {repo_changed_file} because of "{ignored_grok}" in .gitignore file.')
+                    continue
+            repo_changed_files.add(repo_dir_path / repo_changed_file)
+
+        return repo_changed_files
+
     def run(self) -> dict:
         cwd = Path.cwd()
         repo = git.Repo(cwd, search_parent_directories=True)
         repo_dir_path = Path(repo.working_tree_dir)
-        repo_changed_files = {repo_dir_path / item.a_path for item in repo.index.diff(None)}
+        repo_changed_files = self.__get_repo_tracked_modified_files(repo)
         repo_untracked_files = {repo_dir_path / item for item in repo.untracked_files}
         modified_files = {Path(modified_code_file["path"]).resolve() for modified_code_file in self.modified_code_files}
         true_modified_files = modified_files.intersection(repo_changed_files.union(repo_untracked_files))
